.. _dependencies:

Dependencies
============

The only requirement is Python >=3.6. The following dependencies will also be installed:

- xarray_
- dask_
- scipy_
- scikit-image_


.. _xarray:  http://xarray.pydata.org/en/stable/
.. _dask: https://docs.dask.org/en/latest/install.html
.. _scipy: https://scipy.org/scipylib/
.. _scikit-image: https://scikit-image.org/